import React, { useEffect, useState, useRef } from 'react';
/*import './components/my-dog.css';*/
/*import MyDog from './components/my-dog'*/
import './App.css';
import DatePicker from "react-datepicker";
import "react-datepicker/dist/react-datepicker.css";
import classNames from 'classnames';
import Dexie from 'dexie';
const db = new Dexie('todos');
db.version(1).stores({
  todos: 'id,title,date,dueDate'
});

function getId(len) {
  const chars = "0123456789abcdefghijklmnopqrstuvwxyz";
  let val = "";
  for (let i = 0; i < len; ++i) {
      val += chars[Math.floor(Math.random() * chars.length)];
  }
  return val;
}

/*function App() {
  return (
    <div className="App">
      <header className="App-header">
        <div className="my-dog">
        <p>
          <MyDog name={"Duke Fluffy"} age={6} breed={"Golden Retriever"} /><br></br>
          <MyDog name={"Charleston"} age={4} breed={"Pitbull"} /><br></br>
          <MyDog name={"Tail Hazard"} age={2} breed={"German Shepherd"} /><br></br>
          </p>
          </div>
      </header>
    </div>
    
  );
}

export default App; */

function App() {
  const [todos, setTodos] = useState([]);
  /*const myInput = useRef(null);*/
  const [startDate, setStartDate] = useState(new Date());
  const [shiftedIsOn, setShiftedIsOn] = useState(false);
  const titleInput = useRef(null);
  const descriptionInput = useRef(null);
  const creatorInput = useRef(null);
  const assigneeInput = useRef(null);

function loadData() {
  db.todos.toCollection().sortBy('date').then(storedTodos => {
    setTodos(storedTodos);
  })
}

useEffect(() => {
  loadData();
}, []);

async function putItemIntoDatabase() {
  const id = getId(20);
  await db.todos.put({
    id: id,
    title: titleInput.current.value,
    date: Date.now(),
    finished: false,
    creator: creatorInput.current.value,
    assignee: assigneeInput.current.value,
    dueDate: startDate,
    description: descriptionInput.current.value
  });

  loadData();

  titleInput.current.value = "";
  descriptionInput.current.value = "";
}

function setFinished(id) {
  db.todos.update(id, { finished: true });
  loadData();
}

async function deleteTodo(id) {
  await db.todos.delete(id);
  loadData();
}

function handleChange(date) {
  setStartDate(date);
}

function toggleShifted() {
  setShiftedIsOn(!shiftedIsOn);
}

/*function onClick() {
  console.log(myInput.current.value);
}*/

return (
  <div className="App">
    <br />
    <input type="text" placeholder={"Todo title"} ref={titleInput} style={{ padding: 15, fontSize: 20 }}></input>
    <br />
    <input type="text" placeholder={"Creator"} ref={creatorInput} style={{ padding: 15, fontSize: 20 }}></input>
    <br />
    <textarea placeholder="Please describe your todo" ref={descriptionInput}>
    </textarea>
    <br />
    <button className={classNames("buttonTrue")} onClick={putItemIntoDatabase}>Create Todo</button>
    <select ref={assigneeInput}>
      <option value="Megan">Megan</option>
      <option value="Dimitri">Dimitri</option>
      <option value="Kyle">Kyle</option>
      <option value="Tanner">Tanner</option>
    </select>
    <label>Due Date:</label>
    <DatePicker
      selected={startDate}
      onChange={handleChange}
      />
      <br />
      <button className={classNames("shifted")} onClick={toggleShifted}>Toggle Shifted</button>
      {todos.map(todo => {
        return (
          <div key={todo.id} className={classNames("todo-container red", { shifted: shiftedIsOn})}>
          <h2>{todo.title}</h2>
          <p>{todo.description}</p>
          <span>Created Date: {new Date(todo.date).toLocaleString()}</span>
          <br />
          <span>Finished: {todo.finished ? 'yes' : 'no'}</span>
          <br />
          <span>Creator: {todo.creator}</span>
          <br />
          <span>Assignee: {todo.assignee}</span>
          <br />
          <span>Due Date: {todo.dueDate.toLocaleString()}</span>
          <br />
          <button onClick={() => setFinished(todo.id)}>Set Finished</button>
          <button onClick={() => deleteTodo(todo.id)}>DELETE</button>
      </div>
        )
        })}
      {/* Imported component used right here */}
  </div>
);

}

export default App